function [mat, mov]=createMovie(obj,noiseRate,picture)
% create input-movie for demo 'detectMovementByFourier'.
% output is given as matrix (for demoprogram) and 
% movie (for display). 
% input: obj: matrix, defining the mov. direction and number of moving
% objects. e.g.: obj = [1 1; 0 3] creates 2 objects, moving (1,1),(0,2)
% resp.
% noiseRate: background-noise
% picture: background-picture

% define size of movie
sx=150; sy=100; sf=150;
sx=300; sy=200; sf=150;

% if background-picture is given:
% resize to movie-size
% else: create empty picture
if exist('picture')
    picture=im2double(imread(picture));
    picture=imresize(picture,[sy+1 sx+1]);
else
    picture=zeros(sy+1,sx+1);
end


mat=zeros(sy,sx,sf);
for objIndex=1:length(obj(:,1))
    fprintf('\n');
    x=ceil(rand*sx);
    y=ceil(rand*sy);
    dx=obj(objIndex,1);
    dy=obj(objIndex,2);
    
    for f=1:sf
        if mod(f,15)==0 fprintf('.');end
        mat(round(y),round(x),f)=1;
        mat(round(y+1),round(x),f)=1;
        mat(round(y),round(x+1),f)=1;
        mat(round(y+1),round(x+1),f)=1;
        x=mod(x+dx-1,sx)+1;
        y=mod(y+dy-1,sy)+1;
    end
end
mat=mat(1:sy,1:sx,:);


% add noise + background-picture
for f=1:sf
    noise=(rand(sy,sx)>0.99) .* rand(sy,sx);
    pxo=rand>0.99;
    pyo=rand>0.99;
    mat(:,:,f)=mat(:,:,f) + picture(1+pxo:end-1+pxo,1+pyo:end-1+pyo) + noise .* noiseRate;
end
mat=mat/max(mat(:));

% create movie
for f=1:sf
    imshow(mat(:,:,f));
    mov(f)=getframe;
end

return